@@ -27,6 +27,7 @@ import os
 import logging
 import logging.handlers
 import socket
+import platform
 
 try:
     from sip import unwrapinstance
@@ -34,7 +35,6 @@ except ImportError:
     def unwrapinstance(dummy):
         """if there is no sip, we have no Qt objects anyway"""
         pass
-import platform
 
 # pylint: disable=invalid-name
 if platform.python_version_tuple()[0] == '3':
@@ -43,14 +43,20 @@ if platform.python_version_tuple()[0] == '3':
     bytes = bytes
     long = int
     isPython3 = True
+    interpreterName = 'python3'
+    xrange = range
 else:
     # pylint: disable=redefined-builtin
     unicode = unicode
     bytes = str
     long = long
     isPython3 = False
+    if os.name == 'nt':
+        interpreterName = 'python'
+    else:
+        interpreterName = 'python2'
+    xrange = xrange
 
-WINDS = u'ESWN'
 LIGHTSOURCES = [u'NE', u'NW', u'SW', u'SE']
 ENGLISHDICT = {}
 
@@ -109,6 +115,7 @@ class Debug(object):
     quit = False
     preferences = False
     graphics = False
+    scoring = False
 
     def __init__(self):
         raise Exception('Debug is not meant to be instantiated')
@@ -136,8 +143,8 @@ Options are: {opt}.
 Options {stropt} take a string argument like {example}.
 --debug=events can get suboptions like in --debug=events:Mouse:Hide
      showing all event messages with 'Mouse' or 'Hide' in them""".format(
-            opt=opt,
-            stropt=', '.join(stringOptions), example=stringExample)
+         opt=opt,
+         stropt=', '.join(stringOptions), example=stringExample)
 
     @staticmethod
     def setOptions(args):
@@ -152,7 +159,7 @@ Options {stropt} take a string argument like {example}.
             if len(parts) == 1:
                 value = True
             else:
-                value = ':'.join(parts[1:])
+                value = ':'.join(parts[1:]) # pylint: disable=redefined-variable-type
             if option not in Debug.__dict__:
                 return '--debug: unknown option %s' % option
             if not isinstance(Debug.__dict__[option], type(value)):
@@ -215,17 +222,10 @@ class Options(object):
     csv = None
     continueServer = False
     fixed = False
-    server3 = False
 
     def __init__(self):
         raise Exception('Options is not meant to be instantiated')
 
-    @staticmethod
-    def defaultPort():
-        """8000 plus version: for version 4.9.5 we use 8409"""
-        parts = Internal.version.split('.')
-        return 8000 + int(parts[0]) * 100 + int(parts[1])
-
 
 class SingleshotOptions(object):
 
@@ -262,7 +262,10 @@ class __Internal(object):
     """
     # pylint: disable=too-many-instance-attributes
     Preferences = None
-    version = '4.13.0'
+    if isPython3:
+        defaultPort = 8300
+    else:
+        defaultPort = 8200
     logPrefix = 'C'
     isServer = False
     scaleScene = True
@@ -288,6 +291,7 @@ class __Internal(object):
             except (AttributeError, socket.error):
                 haveDevLog = False
         if not haveDevLog:
+            # pylint: disable=redefined-variable-type
             handler = logging.handlers.RotatingFileHandler(
                 'kajongg.log', maxBytes=100000000, backupCount=10)
         self.logger.addHandler(handler)
@@ -342,7 +346,6 @@ class IntDict(defaultdict, StrMixin):
         return result
 
     def __eq__(self, other):
-        # TODO: could be optimized for speed
         return self.all() == other.all()
 
     def __ne__(self, other):
@@ -388,6 +391,12 @@ class IntDict(defaultdict, StrMixin):
                 self.parent[key] -= value
         defaultdict.clear(self)
 
+    def __str__(self):
+        """sort the result for better log comparison"""
+        keys = sorted(self.keys())
+        return ', '.join('{}:{}'.format(
+            str(x), str(self[x])) for x in keys)
+
     def __unicode__(self):
         """sort the result for better log comparison"""
         keys = sorted(self.keys())
@@ -424,8 +433,10 @@ def unicodeString(s, encoding='utf-8'):
         return unicode(s)
     elif isinstance(s, unicode):
         return s
-    else:
+    elif hasattr(s, 'decode'):
         return s.decode(encoding)
+    else:
+        return repr(s)
 
 
 def isStringType(s):
