@@ -29,7 +29,7 @@ from twisted.spread import pb
 from twisted.cred import credentials
 from twisted.internet.defer import CancelledError
 from twisted.internet.task import deferLater
-from twisted.internet.error import ConnectionRefusedError, TimeoutError, ConnectionLost, DNSLookupError, ConnectError
+import twisted.internet.error
 from twisted.python.failure import Failure
 
 from qt import QDialog, QDialogButtonBox, QVBoxLayout, \
@@ -41,8 +41,8 @@ from dialogs import DeferredDialog, QuestionYesNo, MustChooseKDialog
 
 from log import logWarning, logException, logInfo, logDebug, m18n, m18nc, SERVERMARK
 from util import removeIfExists, which
-from common import Internal, Options, SingleshotOptions, Internal, Debug, isAlive, english, unicode
-from common import isPython3, nativeString
+from common import Internal, Options, SingleshotOptions, Debug, isAlive, english, unicode
+from common import isPython3, nativeString, unicodeString, interpreterName
 from game import Players
 from query import Query
 from statesaver import StateSaver
@@ -63,29 +63,24 @@ class Url(unicode):
     # pylint: disable=too-many-public-methods
     # TODO: base content: host:port
     def __new__(cls, url):
+        assert url
         host = None
         port = None
-        if url:
-            urlParts = url.split(':')
-            host = urlParts[0]
-            if english(host) == Query.localServerName:
-                host = '127.0.0.1'
-            if len(urlParts) > 1:
-                port = int(urlParts[1])
-        else:
-            # TODO: but host is None, do we ever get here?
-            url = host
-            if port:
-                url += ':{}'.format(self.port)
+        urlParts = url.split(':')
+        host = urlParts[0]
+        if english(host) == Query.localServerName:
+            host = '127.0.0.1'
+        if len(urlParts) > 1:
+            port = int(urlParts[1])
         obj = unicode.__new__(cls, url)
         obj.host = host
         obj.port = port
         if Options.port:
             obj.port = int(Options.port)
         if obj.port is None and obj.isLocalHost and not obj.useSocket:
-            obj.port = obj.__findFreePort()
+            obj.port = obj.findFreePort()
         if obj.port is None and not obj.isLocalHost:
-            obj.port = Options.defaultPort()
+            obj.port = Internal.defaultPort
         if Debug.connections:
             logDebug(repr(obj))
 
@@ -99,8 +94,6 @@ class Url(unicode):
                 logDebug(u'Installed qt4reactor')
         return obj
 
-        return obj
-
     def __repr__(self):
         """show all info"""
         if self.useSocket:
@@ -114,9 +107,7 @@ class Url(unicode):
         return (
             self.host == '127.0.0.1'
             and os.name != 'nt'
-            and not Options.port
-            and not isPython3
-            and not Options.server3)
+            and not Options.port)
 
     @property
     def isLocalGame(self):
@@ -128,11 +119,11 @@ class Url(unicode):
         """do server and client run on the same host?"""
         return self.host in ('127.0.0.1', 'localhost')
 
-    def __findFreePort(self):
+    def findFreePort(self):
         """find an unused port on the current system.
         used when we want to start a local server on windows"""
         assert self.isLocalHost
-        for port in chain([Options.defaultPort()], range(2000, 19000)):
+        for port in chain([Internal.defaultPort], range(2000, 19000)):
             sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
             sock.settimeout(1)
             try:
@@ -163,38 +154,46 @@ class Url(unicode):
             # riverbank.computing says module dbus is deprecated
             # for Python 3. And Ubuntu has no package with
             # QtDBus. So we use good old subprocess.
-            stdoutdata, stderrdata = subprocess.Popen(['qdbus',
-                                                       'org.kde.kded',
-                                                       '/modules/networkstatus',
-                                                       'org.kde.Solid.Networking.status'], stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
+            stdoutdata, stderrdata = subprocess.Popen(
+                ['qdbus',
+                 'org.kde.kded',
+                 '/modules/networkstatus',
+                 'org.kde.Solid.Networking.status'], stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
             stdoutdata = stdoutdata.strip()
             stderrdata = stderrdata.strip()
             if stderrdata == '' and stdoutdata != '4':
                 # pylint: disable=nonstandard-exception
-                raise ConnectError()
+                raise twisted.internet.error.ConnectError()
             # if we have stderrdata, qdbus probably does not provide the
             # service we want, so ignore it
         return result
 
+    @staticmethod
+    def __findServerProgram():
+        """how should we start the server?"""
+        result = []
+        if sys.argv[0].endswith('kajongg.py'):
+            tryServer = sys.argv[0].replace('.py', 'server.py')
+            if os.path.exists(tryServer):
+                result = [interpreterName, tryServer]
+        elif sys.argv[0].endswith('kajongg.pyw'):
+            tryServer = sys.argv[0].replace('.pyw', 'server.py')
+            if os.path.exists(tryServer):
+                result = [interpreterName, tryServer]
+        elif sys.argv[0].endswith('kajongg.exe'):
+            tryServer = sys.argv[0].replace('.exe', 'server.exe')
+            if os.path.exists(tryServer):
+                result = [tryServer]
+        else:
+            result = ['kajonggserver']
+        if Debug.connections:
+            logDebug(m18n('trying to start local server %1', result))
+        return result
+
     def __startLocalServer(self):
         """start a local server"""
-        # pylint: disable=too-many-branches
-        serverPython = 'python3' if Options.server3 else 'python'
         try:
-            if sys.argv[0].endswith('kajongg.py'):
-                tryServer = sys.argv[0].replace('.py', 'server.py')
-                if os.path.exists(tryServer):
-                    args = [serverPython, tryServer]
-            elif sys.argv[0].endswith('kajongg.pyw'):
-                tryServer = sys.argv[0].replace('.pyw', 'server.py')
-                if os.path.exists(tryServer):
-                    args = [serverPython, tryServer]
-            elif sys.argv[0].endswith('kajongg.exe'):
-                tryServer = sys.argv[0].replace('.exe', 'server.exe')
-                if os.path.exists(tryServer):
-                    args = [tryServer]
-            else:
-                args = ['kajonggserver']
+            args = self.__findServerProgram()
             if self.useSocket or os.name == 'nt':  # for nt --socket tells the server to bind to 127.0.0.1
                 args.append('--socket=%s' % socketName())
                 if removeIfExists(socketName()):
@@ -204,7 +203,9 @@ class Url(unicode):
                 args.append('--port=%d' % self.port)
             if self.isLocalGame:
                 args.append(
-                    '--db={}'.format(os.path.normpath(appdataDir() + 'local.db')))
+                    u'--db={}'.format(
+                        os.path.normpath(
+                            appdataDir() + u'local{}.db'.format('3' if isPython3 else ''))))
             if Debug.argString:
                 args.append('--debug=%s' % Debug.argString)
             if os.name == 'nt':
@@ -561,12 +562,10 @@ class Connection(object):
         Players.createIfUnknown(self.username)
         playerId = Players.allIds[self.username]
         with Internal.db:
-            if Query(
-                'update passwords set password=? where url=? and player=?',
+            if Query('update passwords set password=? where url=? and player=?',
                      (self.password, self.url, playerId)).rowcount() == 0:
-                Query(
-                    'insert into passwords(url,player,password) values(?,?,?)',
-                    (self.url, playerId, self.password))
+                Query('insert into passwords(url,player,password) values(?,?,?)',
+                      (self.url, playerId, self.password))
 
     def __checkExistingConnections(self, dummy=None):
         """do we already have a connection to the wanted URL?"""
@@ -580,7 +579,7 @@ class Connection(object):
     def loginCommand(self, username):
         """send a login command to server. That might be a normal login
         or adduser/deluser/change passwd encoded in the username"""
-        factory = pb.PBClientFactory()
+        factory = pb.PBClientFactory(unsafeTracebacks=True)
         self.connector = self.url.connect(factory)
         utf8Password = self.dlg.password.encode('utf-8')
         utf8Username = username.encode('utf-8')
@@ -629,24 +628,24 @@ class Connection(object):
             raise CancelledError
         if failure.check(CancelledError):
             pass
-        elif failure.check(TimeoutError):
+        elif failure.check(twisted.internet.error.TimeoutError):
             msg = m18n('Server %1 did not answer', self.url)
-        elif failure.check(ConnectionRefusedError):
+        elif failure.check(twisted.internet.error.ConnectionRefusedError):
             msg = m18n('Server %1 refused connection', self.url)
-        elif failure.check(ConnectionLost):
+        elif failure.check(twisted.internet.error.ConnectionLost):
             msg = m18n('Server %1 does not run a kajongg server', self.url)
-        elif failure.check(DNSLookupError):
+        elif failure.check(twisted.internet.error.DNSLookupError):
             msg = m18n('Address for server %1 cannot be found', self.url)
-        elif failure.check(ConnectError):
+        elif failure.check(twisted.internet.error.ConnectError):
             msg = m18n(
                 'Login to server %1 failed: You have no network connection',
                 self.url)
         else:
-            tb = unicodeString(failure.getTraceback())
+            tracebackString = unicodeString(failure.getTraceback())
             msg = u'Login to server {} failed: {}/{} Callstack:{}'.format(
                 self.url, failure.value.__class__.__name__, failure.getErrorMessage(
                 ),
-                tb)
+                tracebackString)
         # Maybe the server is running but something is wrong with it
         if self.url.useSocket:
             if removeIfExists(socketName()):
