@@ -27,6 +27,7 @@ from qt import QString, QSizeF, QSvgRenderer
 from kde import KGlobal, KStandardDirs, KConfig
 from log import logWarning, logException, m18n
 from common import LIGHTSOURCES, Internal
+from wind import East, South, West, North
 
 TILESETVERSIONFORMAT = 1
 
@@ -77,13 +78,14 @@ class Tileset(object):
             # we want default to be first in list
             sortedTilesets = ['default']
             sortedTilesets.extend(tilesets - set(['default']))
-            tilesets = sortedTilesets
+            tilesets = set(sortedTilesets)
         for dontWant in ['alphabet', 'egypt']:
             if dontWant in tilesets:
                 tilesets.remove(dontWant)
         return [Tileset(x) for x in tilesets]
 
-    def __noTilesetFound(self):
+    @staticmethod
+    def __noTilesetFound():
         """No tilesets found"""
         directories = '\n'.join(
             str(x) for x in KGlobal.dirs().resourceDirs("kmahjonggtileset"))
@@ -105,7 +107,7 @@ class Tileset(object):
         if self.path.isEmpty():
             self.path = locateTileset('default.desktop')
             if self.path.isEmpty():
-                self.__noTilesetsFound()
+                self.__noTilesetFound()
             else:
                 logWarning(
                     m18n(
@@ -146,7 +148,7 @@ class Tileset(object):
         # renderer right away
 
         self.svgName = {
-            'wn': 'WIND_1', 'ws': 'WIND_2', 'we': 'WIND_3', 'ww': 'WIND_4',
+            'wn': North.svgName, 'ws': South.svgName, 'we': East.svgName, 'ww': West.svgName,
             'db': 'DRAGON_1', 'dg': 'DRAGON_2', 'dr': 'DRAGON_3'}
         for value in '123456789':
             self.svgName['s%s' % value] = 'ROD_%s' % value
@@ -162,6 +164,7 @@ class Tileset(object):
 
     @staticmethod
     def activeTileset():
+        """the currently wanted tileset. If not yet defined, do so"""
         prefName = Internal.Preferences.tilesetName
         if (not Tileset.__activeTileset
                 or Tileset.__activeTileset.desktopFileName != prefName):
